@@ -1,5 +1,6 @@
 use std::{path::{PathBuf, Path}, fs::File, io::{Seek, Write}, cell::Cell};
 
+use log::debug;
 use ndarray::{ArrayBase, Ix1, Data};
 use serde::{Serialize, Deserialize};
 use byteorder::{BigEndian, ReadBytesExt, WriteBytesExt};
@@ -69,6 +70,8 @@ impl TermsImpacts {
 
     /// Adds a term for a given document
     fn add_impact(&mut self, term_ix: TermIndex, docid: DocId, value: ImpactValue) -> Result<(), std::io::Error> {
+        assert!(value > 0., "Impact values should be greater than 0");
+
         // Adds new vectors for missing words
         if term_ix >= self.postings.len() {
             let d = term_ix - self.postings.len() + 1;
@@ -108,7 +111,8 @@ impl TermsImpacts {
       
         // Get the stream position
         let position = self.postings_file.stream_position()?;
-        // eprintln!("Flush {} at {} (length {})", term_ix, position, len_postings);
+        debug!("Flush {} at {} (length {})", term_ix, position, len_postings);
+
         self.information.terms[term_ix].pages.push(TermIndexPageInformation {
             position: position,
             length: len_postings,
@@ -174,7 +178,8 @@ impl Indexer {
                 .write(true)
                 .create(true)
                 .truncate(true).open(info_path).expect("Error while creating file");
-            ciborium::ser::into_writer(&self.impacts.information, info_file);
+            
+            ciborium::ser::into_writer(&self.impacts.information, info_file).expect("Error while serializing");
 
         } else {
             println!("Already built")
@@ -337,12 +342,14 @@ impl<'a> WandIterator for WandSparseBuilderIndexIterator<'a> {
     fn next(&mut self, doc_id: DocId) -> bool {
         while let Some(v) = self.iterator.next() {
             if v.docid >= doc_id {
+                debug!("[{}] Returning {} ({})", self.iterator.term_ix, v.docid, v.value);
                 self.current_value = v;
                 return true
             }
+            debug!("[{}] Skipping {} ({}) / {}", self.iterator.term_ix, v.docid, v.value, doc_id);
         }
         
-        // println!("[{}] This is over", self.iterator.term_ix);
+        println!("[{}] This is over", self.iterator.term_ix);
         return false
     }
 
