@@ -1,13 +1,14 @@
 #[macro_use]
 extern crate simple_error;
 
-mod tests;
-mod search;
 
+pub mod search;
 pub mod base;
-mod py;
 pub mod index {
     pub mod sparse;
 }
 
+mod py;
 
+#[cfg(test)]
+mod tests;
\ No newline at end of file
