@@ -68,7 +68,7 @@ pub struct PySparseBuilderIndex {
 
 #[pymethods]
 impl PySparseBuilderIndex {
-    fn iter(&self, term: TermIndex) -> PyResult<SparseSparseBuilderIndexIterator> {
+    fn postings(&self, term: TermIndex) -> PyResult<SparseSparseBuilderIndexIterator> {
         let index = self.index.lock().unwrap();
         Ok(SparseSparseBuilderIndexIterator {
             index: self.index.clone(),
